var group__SHAPE__reactivities =
[
    [ "SHAPE.h", "SHAPE_8h.html", null ],
    [ "vrna_sc_add_SHAPE_deigan", "group__SHAPE__reactivities.html#ga57d612b58e1c61dd6cfcb5a843f8f1b3", null ],
    [ "vrna_sc_add_SHAPE_deigan_ali", "group__SHAPE__reactivities.html#ga04ba85da63d8c793bb8001d1e6f800ba", null ],
    [ "vrna_sc_add_SHAPE_zarringhalam", "group__SHAPE__reactivities.html#gaf3c65a045060aef5c4e41693d30af58c", null ],
    [ "vrna_sc_SHAPE_to_pr", "group__SHAPE__reactivities.html#ga67675b3ed48744489a3bcfa4174197cb", null ]
];